@@ -20,6 +20,6 @@ cmake \
 ninja install
 
 # https://github.com/google/benchmark/issues/824
-if [[ `uname -s` == "Linux*" ]]; then
-    sed -i -e 's:/usr/lib/x86_64-linux-gnu/librt.so:-lrt:g' ${PREFIX}/lib/cmake/benchmark/benchmarkTargets.cmake
+if [[ `uname -s` == "Linux" ]]; then
+    sed -i 's:INTERFACE_LINK_LIBRARIES "-pthread;.*:INTERFACE_LINK_LIBRARIES "-pthread;-lrt":g' ${PREFIX}/lib/cmake/benchmark/benchmarkTargets.cmake
 fi
